#!/usr/bin/env python

import argparse
import os.path
import sys

def build_genes_set(genes_file, to_upper = True):
    """Returns a set of genes from a simple file with a gene in every row

    Parameters:

    genes_file (string): the file containing one gene per line
    to_upper (boolean): return all uppercase gene names


    Returns:
    set: The set of all genes in the parsed file
    """

    if os.path.isfile(genes_file) == False:
        print("{} do not exists".format(genes_file), file=sys.stderr)
        return -1

    genes = []

    with open(genes_file) as genes_file:
        for line in genes_file.readlines():
            splitted_line = line.split()
            gene = splitted_line[0]
            if to_upper == True:
                gene = gene.upper()
            genes.append(gene)

    genes = set(genes)
    return genes

def get_genes_from_info(info):
    """Gets the gene names from the INFO columns of a VCF

    Parameters:

    info (string): the INFO field from a VCF variant line


    Returns:
    list: The list of the genes present in the INFO field
    """

    genes = []
    splitted_info = info.split(";")
    for element in splitted_info:
        if element.startswith("ANN="):
            mutations = element.split(",")
            for mutation in mutations:
                splitted_mutation = mutation.split("|")
                gene = splitted_mutation[3]
                genes.append(gene)
    return genes

def main():
    parser = argparse.ArgumentParser(description="Filter a vcf by gene names")
    parser.add_argument('-g', '--genes', action='store', type=str, help="A file with one gene name per line", required=True)
    parser.add_argument('-v', '--vcf', action='store', type=str, help="The VCF to be filtered", required=True)
    parser.add_argument('-m', '--meta', action='store', type=str, help="Show or not show meta-information", required=False, default="T")
    parser.add_argument('-t', '--throw', action='store', type=str, help="Throw away genes present in the file indicated by -g", required=False, default="F")
    args = parser.parse_args()

    genes = args.genes
    vcf = args.vcf
    meta = args.meta
    throw = args.throw

    genes_to_keep_or_trash = build_genes_set(genes)
    
    with open(vcf) as vcf:
        for line in vcf.readlines():
            if line.startswith("#"):
                if meta == "T":
                    print(line[:-1])
                else:
                    pass
            else:
                splitted_line = line.split()
                if len(splitted_line) < 7:
                    pass
                else:
                    info = splitted_line[7]
                    genes = get_genes_from_info(info)
                    for gene in genes:
                        gene = gene.upper()
                        if throw == "F":
                            if gene in genes_to_keep_or_trash:
                                print(line[:-1])
                                break
                        else:
                            if gene not in genes_to_keep_or_trash:
                                print(line[:-1])
                                break
    return 1

if  __name__ == "__main__":
    main()




#!/usr/bin/env python


"""

A script that filters a VCF produced by Strelka2 by these parameters:
    - SDP: number of reads with deletions spanning this site at tier1
    - DP: read depth for tier1 (used+filtered)
    - QSS_NT: Quality score reflecting the joint probability of a somatic variant and NT
    - FDP: Number of basecalls filtered from original read depth for tier1

Read https://sites.google.com/site/strelkasomaticvariantcaller/home/somatic-variant-output for more information on
filtering Strelka2

"""

import argparse
import os.path
import sys

def main():
    parser = argparse.ArgumentParser(description="Filter Strelka2 VCF by SDP / DP, QSS_NT and FDP")
    parser.add_argument('-r', '--ratio', action='store', type=float, help="The ration between SDP and DP should be smaller than -r varlue (default = 0.75)", required=False, default=0.75)
    parser.add_argument('-q', '--qss_nt', action='store', type=float, help="Quality score reflecting the joint probability of a somatic variant and NT", required=False, default=15)
    parser.add_argument('-f', '--fdp', action='store', type=float, help="Number of basecalls filtered from original read depth for tier1", required=False, default=4)
    parser.add_argument('-v', '--vcf', action='store', type=str, help="The vcf to be filtered")
    args = parser.parse_args()
    args = parser.parse_args()

    vcf = args.vcf
    ratio_threshold = args.ratio
    qss_nt_threshold = args.qss_nt
    fdp_threshold = args.fdp

    vcf_exists = os.path.isfile(vcf)
    if vcf_exists == False:
        print("File {} do not exists".format(vcf))
        sys.exit(1)

    is_a_strelka_vcf = False


    # Check if args.vcf is a strelka VCF file
    with open(vcf) as vcf_content:
        for line in vcf_content.readlines():
            if line.startswith("#"):
                if line.startswith("##content=strelka"):
                    is_a_strelka_vcf = True
                    break

        if is_a_strelka_vcf == False:
            sys.exit("Not a strelka VCF")

    vcf_content.close()


    ################### Do the job ##################

    pass_ratio_threshold = False
    pass_qss_nt_threshold = False
    pass_fdp_threshold = False

    with open(vcf) as vcf_content:
        for line in vcf_content.readlines():
            if line.startswith("#"):
                print(line[:-1])
            else:
                splitted_line = line.split()
                splitted_format = splitted_line[10].split(":")
                dp = splitted_format[3]
                sdp = splitted_format[6]
                fdp = int(splitted_format[4])
                ratio = float(sdp) / float(dp)
                if ratio < ratio_threshold:
                    pass_ratio_threshold = True

                info = splitted_line[7]
                splitted_info = info.split(";")
                for single_info in splitted_info:
                    if single_info.startswith("QSS_NT="):
                        qss_nt = single_info[7:]
                        qss_nt = int(qss_nt)
                        if qss_nt > qss_nt_threshold:
                            pass_qss_nt_threshold = True


                if fdp <= pass_fdp_threshold:
                    pass_fdp_threshold = True

                if pass_ratio_threshold and pass_qss_nt_threshold and pass_fdp_threshold:
                    #print(pass_ratio_threshold, pass_qss_nt_threshold, pass_fdp_threshold)
                    print(line[:-1])

 

if  __name__ == "__main__":
    main()



#!/usr/bin/env python

__author__ = "Alessandro Coppe"

'''
Given a set of directories with VarScan2 VCFs obtained from iWhale or vs_format_converter.py (varscan_accessories)
it filters it using somaticFilter command from varscan.jar software
'''

import argparse
import os.path
import os
import sys
import pathlib
import subprocess


class bcolors:
    OKGREEN = '\033[92m'
    ERROR   = '\033[91m'
    ENDC    = '\033[0m'


def main():
    parser = argparse.ArgumentParser(description="Filter out VCFS produced by VarScan2")
    parser.add_argument('-c', '--min_coverage', action='store', type=int, help="Minimum read depth [20]", required=False, default=20)
    parser.add_argument('-r', '--min_reads2', action='store', type=int, help="Minimum supporting reads for a variant [5]", required=False, default=5)
    parser.add_argument('-s', '--min_strands2', action='store', type=int, help="Minimum # of strands on which variant observed (1 or 2) [1]", required=False, default=1)
    parser.add_argument('-q', '--min_avg_qual', action='store', type=int, help="Minimum average base quality for variant-supporting reads [30]", required=False, default=30)
    parser.add_argument('-f', '--min_var_freq', action='store', type=float, help="Minimum variant allele frequency threshold [0.05]", required=False, default=0.05)
    parser.add_argument('-p', '--p_value', action='store', type=float, help="Default p-value threshold for calling variants [0.05]", required=False, default=0.05)
    parser.add_argument('-d', '--directory', action='store', type=str, help="The directory containing VarScan2 VCFs", required=False, default='.')
    parser.add_argument('-o', '--output_directory', action='store', type=str, help="The output directory", required=False, default='.')
    args = parser.parse_args()

    min_coverage     = args.min_coverage
    min_reads2       = args.min_reads2
    min_strands2     = args.min_strands2
    min_avg_qual     = args.min_avg_qual
    min_var_freq     = args.min_var_freq
    p_value          = args.p_value
    directory        = args.directory
    output_directory = args.output_directory

    if os.path.isdir(directory) == False:
        print(bcolors.ERROR + "{} is not a directory".format(directory) + bcolors.ENDC )
        sys.exit()

    if os.path.isdir(output_directory) == False:
        print(bcolors.ERROR + "{} is not a directory".format(output_directory) + bcolors.ENDC )
        sys.exit()

    for entry in os.listdir(directory):
        path = os.path.join(directory, entry)
        if os.path.isfile(path):
            spliced_input_name = entry.split("_")
            spliced_input_name = spliced_input_name[:len(spliced_input_name) - 1]
            spliced_input_name = "_".join(spliced_input_name)
            output_name = spliced_input_name + "_varscan_filtered.vcf"
            output_file_path = os.path.join(output_directory, output_name)

            command = ["java", "-jar", "/home/ale/local/varscan.jar", "somaticFilter", path, "--output-file", output_file_path, "--min-coverage", str(min_coverage), "--min-reads2", str(min_reads2), "--min-strands2", str(min_strands2), "--min-avg-qual", str(min_avg_qual), "--min-var-freq", str(min_var_freq), "--p-value", str(p_value)]
            print(bcolors.OKGREEN + " ".join(command) + bcolors.ENDC)
            subprocess.run(command)

if __name__ == "__main__":
    main()



#!/usr/bin/env python

import argparse
import os.path
import sys
import gzip


def snps_from_cosmic(cosmic_file):
    """
    Removes the SNPs from COSMIC

    Parameters:

    cosmic_file (string): the file from COSMIC (like: CosmicCodingMuts.vcf.gz)


    Returns:
    set: The set of all cosmic IDs that are a SNP
    """

    cosmic_snps = []
    with gzip.open(cosmic_file, 'rb') as f:
        for line in f:
            line = line.decode('ascii')
            if not line.startswith("#"):
                splitted_line = line.split()
                cosmic_id = splitted_line[2]
                info = splitted_line[-1]
                splitted_info = info.split(";")
                for splitted_info_point in splitted_info:
                    if splitted_info_point == "SNP":
                        cosmic_snps.append(cosmic_id)
                        break
    return set(cosmic_snps)


def main():
    parser = argparse.ArgumentParser(description="Removes the SNPs from COSMIC")
    parser.add_argument('-c', '--cosmic', action='store', type=str, help="The file from Cosmic (Example: CosmicCodingMuts.vcf.gz)", required=True)
    parser.add_argument('-v', '--vcf', action='store', type=str, help="The VCF to be filtered by SNPs from COSMIC", required=True)
    args = parser.parse_args()

    cosmic_snps = snps_from_cosmic(args.cosmic)

    with open(args.vcf) as vcf:
        for line in vcf:
            if line.startswith("#"):
                print(line[:-1])
            else:
                splitted_line = line.split("\t")
                ids = splitted_line[2]
                splitted_ids = ids.split(";")
                for identifier in splitted_ids:
                    if identifier.startswith("COSM") or identifier.startswith("COSM"):
                        is_snp = identifier in cosmic_snps
                        if not  is_snp:
                            #print(is_snp)
                            print(line[:-1])
                    if identifier == "." or identifier.startswith("rs"):
                        print(line[:-1])

if  __name__ == "__main__":
    main()



#!/usr/bin/env python

import argparse
import os.path
import sys
import zipfile

def find_expressed_variants(vcf, thpa_dictionary):
    vcf_exists = False
    vcf_exists = os.path.isfile(vcf)
    if vcf_exists == False:
        print("File {} do not exists".format(vcf))
        sys.exit(1)

    with open(vcf) as vcf_content:
        for line in vcf_content.readlines():
            if line.startswith("#"):
                print(line[:-1])
            else:
                splitted_line = line.split("\t")
                info = splitted_line[7]
                splitted_info= info.split(";")
                for each_element in splitted_info:
                    if each_element.startswith("ANN="):
                        transcripts_info = each_element[4:]
                        splitted_transcript_info = transcripts_info.split(",")
                        for transcript in splitted_transcript_info:
                            splitted_transcript = transcript.split("|")
                            gene_id,ensg = splitted_transcript[3],splitted_transcript[4]
                            expression_value = thpa_dictionary.get(gene_id)
                            if expression_value != None:
                                print(line[:-1])
                                break
    return 0



def build_thpa_dictionary(normal_tissue_file_path, cell_types = ["B-cells", "NK-cells", "T-cells", "bone marrow", "dendritic cells", "granulocytes", "monocytes"], min_nx = 1):
    d = {}
    zfile = zipfile.ZipFile(normal_tissue_file_path)
    cell_types = set(cell_types)
    for finfo in zfile.infolist():
        if finfo.filename == 'rna_tissue_consensus.tsv':
            ifile = zfile.open(finfo)
            line_list = ifile.readlines()
            for line in line_list:
                line = str(line).replace("\\t", "\t")
                splitted_line = line.split("\t")
                tissue = splitted_line[2]
                nx = splitted_line[3]
                try:
                    nx = float(nx[:-3])
                except:
                    continue
                if tissue in cell_types and nx >= min_nx:
                    if not (splitted_line[1] in d):
                        d[splitted_line[1]] = [splitted_line[2]]
                    else:
                        d[splitted_line[1]].append(splitted_line[2])
    return(d)
    


def main():
    parser = argparse.ArgumentParser(description="Filter by rna_tissue_consensus.tsv.zip consensus transcript expression levels")
    parser.add_argument('-n', '--normal_tissue', action='store', type=str, help="rna_tissue_consensus.tsv.zip file path", required=True, default=None)
    parser.add_argument('-v', '--vcf', action='store', type=str, help="VCF to be filtered", required=True, default=None)
    parser.add_argument('-x', '--nx', action='store', type=int, help="Minimum transcript expression value, denoted Normalized eXpression (NX)", required=False, default=1)
    args = parser.parse_args()

    normal_tissue = args.normal_tissue
    vcf = args.vcf
    nx = args.nx

    thpa_dictionary = build_thpa_dictionary(normal_tissue, min_nx = nx)
    find_expressed_variants(vcf, thpa_dictionary)

    
if  __name__ == "__main__":
    main()




#!/usr/bin/env python

import argparse
import os.path
import sys


def get_genes_from_lgldb(lgld):
    """Parse the file downloaded from Leukemia gene and literature database (dbLGL)

    Parameters:

    lgld (string): the path of the downloaded file from dbLGL


    Returns:
    list:The list of genes from dbLGL
    """
    if os.path.isfile(lgld) == False:
        print("{} do not exists".format(lgld), file=sys.stderr)
        return -1
    
    genes_from_lgldb = []

    with open(lgld) as lgld:
        for line in lgld.readlines():
            splitted_line = line.split()
            if len(splitted_line) > 3:
                gene_symbol = splitted_line[1]
                genes_from_lgldb.append(gene_symbol)
                aliases = splitted_line[2].split("|")
                if aliases != ["-"]:
                    for alias in aliases: genes_from_lgldb.append(alias)
    return list(set(genes_from_lgldb))


def get_genes_from_cosmic(cosmic):
    """Parse the file downloaded from Catalogue of Somatic Mutations In Cancer (COSMIC)

    Parameters:

    cosmic (string): the path of the cancer_gene_census.csv file downloaded from COSMIC


    Returns:
    list:The list of genes from COSMIC
    """

    if os.path.isfile(cosmic) == False:
        print("{} do not exists".format(cosmic, file=sys.stderr))
        return -1

    genes_from_cosmic = []

    with open(cosmic) as cosmic:
        for line in cosmic.readlines():
            splitted_line = line.split(",")
            gene_symbol = splitted_line[0]
            genes_from_cosmic.append(gene_symbol)

            splitted_line = line.split('\"')
            if len(splitted_line) > 1:
                synonyms = splitted_line[-2].split(',')
                for synonym in synonyms: genes_from_cosmic.append(synonym)
    return list(set(genes_from_cosmic))



def main():
    parser = argparse.ArgumentParser(description="Builds a list of leukemia genes from Leukemia Gene Literature Database and COSMIC")
    parser.add_argument('-l', '--lgld', action='store', type=str, help="The flat file from human cancer leukemia genes", required=True)
    parser.add_argument('-c', '--cosmic', action='store', type=str, help="The flat file from COSMIC's Cancer Gene Census (CGC)", required=True)
    args = parser.parse_args()

    lgld = args.lgld
    cosmic = args.cosmic

    genes_from_lgldb = get_genes_from_lgldb(lgld)
    genes_from_cosmic = get_genes_from_cosmic(cosmic)

    genes_from_lgldb = set(genes_from_lgldb)
    all_genes = list(genes_from_lgldb.union(genes_from_cosmic))

    for gene in all_genes:
        print(gene)

    return 1

if  __name__ == "__main__":
    main()




import setuptools


#scripts=['change_set_subfield'] ,

setuptools.setup(
     name='iSeqs2',  
     version='0.0.2',
     author="Alessandro Coppe",
     author_email="",
     description="Another bunch of scripts I use in my Next Generation Sequencing Bioinformatics Analyses",
     url="https://github.com/alexcoppe/iSeqs2",
     packages=["iseqs2"],
     scripts=["scripts/build_leukemia_genes_list/build_leukemia_genes_list.py",
         "scripts/filter_by_normal_expression/filter_by_normal_expression.py",
         "scripts/filter_strelka2/filter_strelka2.py",
         "scripts/remove_snps_from_cosmic/remove_snps_from_cosmic.py",
         "scripts/filter_vcf_by_gene_names/filter_vcf_by_gene_names.py",
         "scripts/filter_varscan2_vcfs/filter_varscan2_vcfs.py",
         "scripts/join_tables_from_snpsift_extractFields/join_tables_from_snpsift_extractFields.py"],
     classifiers=[
         "Programming Language :: Python :: 3",
         "License :: OSI Approved :: MIT License",
         "Operating System :: OS Independent",
     ],
)



#!/usr/bin/env python

__author__ = "Alessandro Coppe"

'''
Given tables created by............................
'''

import argparse
import os.path
import os
import sys
import pathlib
import subprocess


class bcolors:
    OKGREEN = '\033[92m'
    ERROR   = '\033[91m'
    ENDC    = '\033[0m'



def get_info_from_patient_mutation(format, patient_data, caller):
    returned_dict = {}
    if "\n" in patient_data:
        patient_data = patient_data[:-1]
    patient_data = patient_data.split(":")
    # GT: genotype
    gt = patient_data[0]
    returned_dict["gt"] = gt

    if caller == "mutect2" or caller == "mutect":
        # Allelic depths for the ref and alt alleles in the order listed
        AD_alleles_depth = patient_data[1]
        normal = AD_alleles_depth.split(",")[0]
        tumor = AD_alleles_depth.split(",")[1]
        vaf = float(tumor) / ( float(tumor) + float(normal))
        coverage = int(tumor) + int(normal)
        returned_dict["vaf"] = vaf
        returned_dict["coverage"] = coverage
        returned_dict["normal"] = normal
        returned_dict["tumor"] = tumor

    if caller == "varscan":
        # DP: Read Depth (coverage) Total depth of quality bases
        coverage = patient_data[2]
        # RD: Depth of reference-supporting base
        normal = patient_data[2]
        # AD: Depth of variant-supporting bases (reads2) tumor bases
        tumor = patient_data[3]
        # FREQ: Variant allele frequency
        vaf = float(tumor) / ( float(tumor) + float(normal))
        returned_dict["coverage"] = coverage
        returned_dict["normal"] = normal
        returned_dict["tumor"] = tumor
        returned_dict["vaf"] = vaf

    if caller == "strelka":
        nucleotides_freq = {"a": patient_data[1],
                "c": patient_data[2],
                "g": patient_data[5],
                "t": patient_data[8]}
        keys = nucleotides_freq.keys()
        values = nucleotides_freq.values()
        new_values = [int(el.split(",")[0]) for el in values]
        new_nucleotides_freq = dict(zip(keys, new_values))
        new_values.sort()
        coverage = sum(new_values)
        # DP: Read Depth
        coverage = sum(new_values)
        # RD: Depth of reference-supporting base
        rd = sum(new_values) - sum(new_values[:-1])
        # AD: Depth of variant-supporting bases (reads2)
        ad = new_values[-2]
        normal_nucleotide_freq = new_values[-1]
        tumor_nucleotide_freq = new_values[-2]
        frequency = float(tumor_nucleotide_freq) / (tumor_nucleotide_freq + normal_nucleotide_freq)
        returned_dict["normal"] = normal_nucleotide_freq
        returned_dict["tumor"] = tumor_nucleotide_freq
        returned_dict["vaf"] = frequency
        returned_dict["coverage"] = int(tumor_nucleotide_freq) + int(normal_nucleotide_freq)


    return returned_dict


def build_output_line(line, caller):
    # It returns:
    # CHROM POITION IDS ALTERNATIVE NORMAL PASS CLNSIG 1/0 COVERAGE TUMOR NORMAL VAF GENE EFFECT
    splitted_line = line.split("\t")
    first_part_of_output = splitted_line[0:6]
    splitted_effects = splitted_line[7].split(",")
    splitted_genes = splitted_line[6].split(",")
    genes_effects = list(zip(splitted_genes,splitted_effects))
    genes_effects = list(set(genes_effects))
    genes_effects = [g_e for g_e in genes_effects if g_e[1] in ["MODERATE", "HIGH"]]
    clnsig = splitted_line[8]
    first_part_of_output.append(clnsig)
    file_format = splitted_line[9]
    if caller == "mutect2":
        gt1 = splitted_line[11].split(":")[0]
        gt2 = splitted_line[10].split(":")[0]
        if gt1 == "0/1" or gt1 == "1/0":
            tumor_data = 11
        else:
            tumor_data = 10
        tumor_data = get_info_from_patient_mutation(file_format, splitted_line[tumor_data], "mutect2")
        #normal_data = get_info_from_patient_mutation(file_format, splitted_line[10], "mutect2")
    if caller == "mutect":
        gt1 = splitted_line[11].split(":")[0]
        gt2 = splitted_line[10].split(":")[0]
        if gt1 == "0/1" or gt1 == "1/0":
            tumor_data = 11
        else:
            tumor_data = 10
        tumor_data = get_info_from_patient_mutation(file_format, splitted_line[tumor_data], "mutect")
    # Check if variants with normal high VAF are rigth
    if caller == "varscan":
        tumor_data = get_info_from_patient_mutation(file_format, splitted_line[11], "varscan")
    if caller == "strelka":
        tumor_data = get_info_from_patient_mutation(file_format, splitted_line[11], "strelka")


    first_part_of_output.append(tumor_data.get("gt"))
    first_part_of_output.append(str(tumor_data.get("coverage")))
    first_part_of_output.append(str(tumor_data.get("tumor")))
    first_part_of_output.append(str(tumor_data.get("normal")))
    first_part_of_output.append(str(tumor_data.get("vaf")))
    effects = []
    for gene_effect in genes_effects:
        effects.append(gene_effect[1])
    gene = gene_effect[0]
    if "HIGH" in effects:
        effect = "HIGH"
    else:
        effect = "MODERATE"

    first_part_of_output.append(gene)
    first_part_of_output.append(effect)
    #print(first_part_of_output)
    return first_part_of_output


def main():
    parser = argparse.ArgumentParser(description="Join all the tables produced by SnpSift extractFields")
    parser.add_argument('-d', '--directory', action='store', type=str, help="The directory containing all the files to be joined", required=True)
    parser.add_argument('-o', '--output_directory', action='store', type=str, help="The output directory", required=False, default='.')
    args = parser.parse_args()

    directory = args.directory
    output_directory = args.output_directory

    if os.path.isdir(directory) == False:
        print(bcolors.ERROR + "{} is not a directory".format(directory) + bcolors.ENDC )
        sys.exit()

    if os.path.isdir(output_directory) == False:
        print(bcolors.ERROR + "{} is not a directory".format(output_directory) + bcolors.ENDC )
        sys.exit()

    variants = {}

    all_files = os.listdir(directory)
    all_files.sort()
    sample_names = list(set(["_".join(f.split("_")[:4]) for f in all_files]))
    for sample in sample_names:
        mutations = {}
        mutation_lines = {}
        sample_files = [f for f in all_files if f.startswith(sample)]

        for entry in sample_files:
            if "_mutect2_" in entry:
                f = open(os.path.join(directory, entry))
                for line in f:
                    if not line.startswith("#") and not line.startswith("CHROM"):
                        output_line = "\t".join(build_output_line(line, "mutect2"))
                        the_key = output_line.split("\t")[0] + output_line.split("\t")[1]
                        if the_key not in mutation_lines.keys():
                            mutation_lines[the_key] = []
                            mutation_lines[the_key] = output_line
                        if  the_key not in mutations.keys():
                            mutations[the_key] = []
                            mutations[the_key].append("mutect2")
                        else:
                            mutations[the_key].append("mutect2")

            elif "_mutect_" in entry:
                f = open(os.path.join(directory, entry))
                for line in f:
                    if not line.startswith("#") and not line.startswith("CHROM"):
                        output_line = "\t".join(build_output_line(line, "mutect"))
                        the_key = output_line.split("\t")[0] + output_line.split("\t")[1]
                        if the_key not in mutation_lines.keys():
                            mutation_lines[the_key] = []
                            mutation_lines[the_key] = output_line
                        if  the_key not in mutations.keys():
                            mutations[the_key] = []
                            mutations[the_key].append("mutect")
                        else:
                            mutations[the_key].append("mutect")


            elif "varscan" in entry or "varscan2" in entry:
                f = open(os.path.join(directory, entry))
                for line in f:
                    if not line.startswith("#") and not line.startswith("CHROM"):
                        output_line = "\t".join(build_output_line(line, "varscan"))
                        the_key = output_line.split("\t")[0] + output_line.split("\t")[1]
                        if the_key not in mutation_lines.keys():
                            mutation_lines[the_key] = []
                            mutation_lines[the_key] = output_line
                        if  the_key not in mutations.keys():
                            mutations[the_key] = []
                            mutations[the_key].append("varscan")
                        else:
                            mutations[the_key].append("varscan")


            elif "strelka2" in entry or "strelka" in entry:
                f = open(os.path.join(directory, entry))
                for line in f:
                    if not line.startswith("#") and not line.startswith("CHROM"):
                        output_line = "\t".join(build_output_line(line, "strelka"))
                        the_key = output_line.split("\t")[0] + output_line.split("\t")[1]
                        if the_key not in mutation_lines.keys():
                            mutation_lines[the_key] = []
                            mutation_lines[the_key] = output_line
                        if  the_key not in mutations.keys():
                            mutations[the_key] = []
                            mutations[the_key].append("strelka")
                        else:
                            mutations[the_key].append("strelka")


        for key in mutations:
            first_part_of_output = mutation_lines.get(key)
            variant_callers = set(mutations.get(key))
            variant_callers = "-".join(variant_callers)
            entire_line = first_part_of_output + "\t" + variant_callers + "\t" + sample
            print(entire_line)



if __name__ == "__main__":
    main()
